summaryrefslogtreecommitdiff
path: root/sd/inc
diff options
context:
space:
mode:
Diffstat (limited to 'sd/inc')
-rwxr-xr-xsd/inc/Outliner.hxx38
-rwxr-xr-x[-rw-r--r--]sd/inc/anminfo.hxx20
-rwxr-xr-xsd/inc/drawdoc.hxx144
-rwxr-xr-xsd/inc/glob.hxx8
-rwxr-xr-xsd/inc/pch/precompiled_sd.hxx3
-rwxr-xr-xsd/inc/sdabstdlg.hxx32
-rwxr-xr-x[-rw-r--r--]sd/inc/sdattr.hxx22
-rwxr-xr-x[-rw-r--r--]sd/inc/sderror.hxx4
-rwxr-xr-x[-rw-r--r--]sd/inc/sdgrffilter.hxx2
-rwxr-xr-x[-rw-r--r--]sd/inc/sdhtmlfilter.hxx2
-rwxr-xr-x[-rw-r--r--]sd/inc/sdiocmpt.hxx20
-rwxr-xr-xsd/inc/sdmod.hxx14
-rwxr-xr-xsd/inc/sdpage.hxx80
-rwxr-xr-x[-rw-r--r--]sd/inc/sdresid.hxx2
-rwxr-xr-x[-rw-r--r--]sd/inc/sdxmlwrp.hxx4
-rwxr-xr-xsd/inc/stlpool.hxx2
-rwxr-xr-x[-rw-r--r--]sd/inc/stlsheet.hxx20
-rwxr-xr-x[-rw-r--r--]sd/inc/undo/undomanager.hxx20
18 files changed, 213 insertions, 224 deletions
diff --git a/sd/inc/Outliner.hxx b/sd/inc/Outliner.hxx
index dfc7e3e3bf88..45db437e9370 100755
--- a/sd/inc/Outliner.hxx
+++ b/sd/inc/Outliner.hxx
@@ -120,7 +120,7 @@ public:
<const>OUTLINERMODE_OUTLINEVIEW</const> are defined in
editeng/outliner.hxx.
*/
- Outliner( SdDrawDocument* pDoc, USHORT nMode );
+ Outliner( SdDrawDocument* pDoc, sal_uInt16 nMode );
virtual ~Outliner();
/** Despite the name this method is called prior to spell cheking *and*
@@ -141,8 +141,8 @@ public:
/** Initiate a find and/or replace on the next relevant text object.
@return
- Returns </TRUE> when the search/replace is finished (as
- indicated by user input to the search dialog). A </FALSE> value
+ Returns </sal_True> when the search/replace is finished (as
+ indicated by user input to the search dialog). A </sal_False> value
indicates that another call to this method is required.
*/
bool StartSearchAndReplace (const SvxSearchItem* pSearchItem);
@@ -163,8 +163,8 @@ public:
/** Starts the text conversion (hangul/hanja or Chinese simplified/traditional)
for the current viewshell */
- void StartConversion( INT16 nSourceLanguage, INT16 nTargetLanguage,
- const Font *pTargetFont, INT32 nOptions, BOOL bIsInteractive );
+ void StartConversion( sal_Int16 nSourceLanguage, sal_Int16 nTargetLanguage,
+ const Font *pTargetFont, sal_Int32 nOptions, sal_Bool bIsInteractive );
/** This is called internaly when text conversion is started.
The position of current view mode/page/object/caret position
@@ -203,7 +203,7 @@ private:
/** this is the language that is used for current text conversion.
Only valid if meMode is TEXT_CONVERSION.
*/
- INT16 mnConversionLanguage;
+ sal_Int16 mnConversionLanguage;
/** While the value of this flag is greater than 0 changes of the current page
do not lead to selecting the corresponding text in the outliner.
@@ -215,17 +215,17 @@ private:
/** This flag indicates whether there may exist a match of the search
string before/after the current position in the document. It can be
- set to </FALSE> only when starting from the beginning/end of the
+ set to </sal_False> only when starting from the beginning/end of the
document. When reaching the end/beginning with it still be set to
- </FALSE> then there exists no match and the search can be terminated.
+ </sal_False> then there exists no match and the search can be terminated.
*/
bool mbMatchMayExist;
/// The number of pages in the current view.
- USHORT mnPageCount;
+ sal_uInt16 mnPageCount;
/// Number of objects on the current page / in the current selection.
- INT32 mnObjectCount;
+ sal_Int32 mnObjectCount;
/** A <TRUE/> value indicates that the end of the find&replace or spell
check has been reached.
@@ -234,7 +234,7 @@ private:
/** Set to <TRUE/> when an object has been prepared successfully for
searching/spell checking. This flag directs the internal iteration
- which stops when set to </TRUE>.
+ which stops when set to </sal_True>.
*/
bool mbFoundObject;
@@ -296,7 +296,7 @@ private:
EditMode meStartEditMode;
/// The current page index on starting to search/spell check.
- USHORT mnStartPageIndex;
+ sal_uInt16 mnStartPageIndex;
/// The object in edit mode when searching /spell checking was started
/// (if any).
@@ -369,8 +369,8 @@ private:
/** Do search and replace for next match.
@return
- The return value specifies whether the search ended (</TRUE>) or
- another call to this method is required (</FALSE>).
+ The return value specifies whether the search ended (</sal_True>) or
+ another call to this method is required (</sal_False>).
*/
bool SearchAndReplaceOnce (void);
@@ -409,7 +409,7 @@ private:
/** Handle the situation that the iterator has reached the last object.
This may result in setting the <member>mbEndOfSearch</member> flag
- back to </FALSE>. This method may show either the end-of-search
+ back to </sal_False>. This method may show either the end-of-search
dialog or the wrap-arround dialog.
*/
void EndOfSearch (void);
@@ -469,11 +469,11 @@ private:
@param nPageIndex
The new page index.
*/
- void SetPage (EditMode eEditMode, USHORT nPageIndex);
+ void SetPage (EditMode eEditMode, sal_uInt16 nPageIndex);
/** Switch on edit mode for the currently selected text object.
*/
- void EnterEditMode (BOOL bGrabFocus=TRUE);
+ void EnterEditMode (sal_Bool bGrabFocus=sal_True);
/** Return the position at which a new search is started with respect to
the search direction as specified by the argument.
@@ -537,14 +537,14 @@ private:
required. When all text objects have been processed then
<FALSE/> is returned.
*/
- virtual BOOL SpellNextDocument (void);
+ virtual sal_Bool SpellNextDocument (void);
/** Show the given message box and make it modal. It is assumed that
the parent of the given dialog is NULL, i.e. the application
window. This function makes sure that the otherwise non-modal
search dialog, if visible, is locked, too.
*/
- USHORT ShowModalMessageBox (Dialog& rMessageBox);
+ sal_uInt16 ShowModalMessageBox (Dialog& rMessageBox);
};
} // end of namespace sd
diff --git a/sd/inc/anminfo.hxx b/sd/inc/anminfo.hxx
index 5788e0f32ce5..9204a02430fd 100644..100755
--- a/sd/inc/anminfo.hxx
+++ b/sd/inc/anminfo.hxx
@@ -54,25 +54,25 @@ public:
::com::sun::star::presentation::AnimationEffect meEffect; // Animationseffekt
::com::sun::star::presentation::AnimationEffect meTextEffect; // Animationseffekt fuer Textinhalt
::com::sun::star::presentation::AnimationSpeed meSpeed; // Geschwindigkeit der Animation
- BOOL mbActive; // eingeschaltet ?
- BOOL mbDimPrevious; // Objekt abblenden
- BOOL mbIsMovie; // wenn Gruppenobjekt, dann Sequenz aus den
- BOOL mbDimHide; // verstecken statt abblenden
+ sal_Bool mbActive; // eingeschaltet ?
+ sal_Bool mbDimPrevious; // Objekt abblenden
+ sal_Bool mbIsMovie; // wenn Gruppenobjekt, dann Sequenz aus den
+ sal_Bool mbDimHide; // verstecken statt abblenden
Color maBlueScreen; // identifiziert "Hintergrundpixel"
Color maDimColor; // zum Abblenden des Objekts
String maSoundFile; // Pfad zum Soundfile in MSDOS-Notation
- BOOL mbSoundOn; // Sound ein/aus
- BOOL mbPlayFull; // Sound ganz abspielen
+ sal_Bool mbSoundOn; // Sound ein/aus
+ sal_Bool mbPlayFull; // Sound ganz abspielen
SdrPathObj* mpPathObj; // das Pfadobjekt
::com::sun::star::presentation::ClickAction meClickAction; // Aktion bei Mausklick
::com::sun::star::presentation::AnimationEffect meSecondEffect; // fuer Objekt ausblenden
::com::sun::star::presentation::AnimationSpeed meSecondSpeed; // fuer Objekt ausblenden
String maSecondSoundFile; // fuer Objekt ausblenden
- BOOL mbSecondSoundOn; // fuer Objekt ausblenden
- BOOL mbSecondPlayFull;// fuer Objekt ausblenden
+ sal_Bool mbSecondSoundOn; // fuer Objekt ausblenden
+ sal_Bool mbSecondPlayFull;// fuer Objekt ausblenden
// String maBookmark; // Sprung zu Objekt/Seite
- USHORT mnVerb; // fuer OLE-Objekt
- ULONG mnPresOrder;
+ sal_uInt16 mnVerb; // fuer OLE-Objekt
+ sal_uLong mnPresOrder;
SdrObject& mrObject;
SD_DLLPUBLIC void SetBookmark( const String& rBookmark );
diff --git a/sd/inc/drawdoc.hxx b/sd/inc/drawdoc.hxx
index 7cdee6a4efa5..2ff8f98b65dd 100755
--- a/sd/inc/drawdoc.hxx
+++ b/sd/inc/drawdoc.hxx
@@ -171,8 +171,8 @@ private:
List* mpCustomShowList;
::sd::DrawDocShell* mpDocSh;
SdTransferable * mpCreatingTransferable;
- BOOL mbHasOnlineSpellErrors;
- BOOL mbInitialOnlineSpellingEnabled;
+ sal_Bool mbHasOnlineSpellErrors;
+ sal_Bool mbInitialOnlineSpellingEnabled;
String maBookmarkFile;
::sd::DrawDocShellRef mxBookmarkDocShRef;
@@ -180,17 +180,17 @@ private:
::com::sun::star::uno::Reference< ::com::sun::star::presentation::XPresentation2 > mxPresentation;
- BOOL mbNewOrLoadCompleted;
+ sal_Bool mbNewOrLoadCompleted;
- BOOL mbOnlineSpell;
- BOOL mbSummationOfParagraphs;
+ sal_Bool mbOnlineSpell;
+ sal_Bool mbSummationOfParagraphs;
bool mbStartWithPresentation; // is set to true when starting with command line parameter -start
LanguageType meLanguage;
LanguageType meLanguageCJK;
LanguageType meLanguageCTL;
SvxNumType mePageNumType;
::sd::DrawDocShellRef mxAllocedDocShRef; // => AllocModel()
- BOOL mbAllocDocSh; // => AllocModel()
+ sal_Bool mbAllocDocSh; // => AllocModel()
DocumentType meDocType;
CharClass* mpCharClass;
::com::sun::star::lang::Locale* mpLocale;
@@ -199,8 +199,8 @@ private:
::std::auto_ptr<ImpDrawPageListWatcher> mpDrawPageListWatcher;
::std::auto_ptr<ImpMasterPageListWatcher> mpMasterPageListWatcher;
- void UpdatePageObjectsInNotes(USHORT nStartPos);
- void UpdatePageRelativeURLs(SdPage* pPage, USHORT nPos, sal_Int32 nIncrement);
+ void UpdatePageObjectsInNotes(sal_uInt16 nStartPos);
+ void UpdatePageRelativeURLs(SdPage* pPage, sal_uInt16 nPos, sal_Int32 nIncrement);
void FillOnlineSpellingList(SdPage* pPage);
void SpellObject(SdrTextObj* pObj);
@@ -233,21 +233,21 @@ public:
SfxItemPool& GetPool() { return( *pItemPool ); }
- ::sd::Outliner* GetOutliner(BOOL bCreateOutliner=TRUE);
- SD_DLLPUBLIC ::sd::Outliner* GetInternalOutliner(BOOL bCreateOutliner=TRUE);
+ ::sd::Outliner* GetOutliner(sal_Bool bCreateOutliner=sal_True);
+ SD_DLLPUBLIC ::sd::Outliner* GetInternalOutliner(sal_Bool bCreateOutliner=sal_True);
::sd::DrawDocShell* GetDocSh() const { return mpDocSh; }
- LanguageType GetLanguage( const USHORT nId ) const;
- void SetLanguage( const LanguageType eLang, const USHORT nId );
+ LanguageType GetLanguage( const sal_uInt16 nId ) const;
+ void SetLanguage( const LanguageType eLang, const sal_uInt16 nId );
SvxNumType GetPageNumType() const;
void SetPageNumType(SvxNumType eType) { mePageNumType = eType; }
- SD_DLLPUBLIC String CreatePageNumValue(USHORT nNum) const;
+ SD_DLLPUBLIC String CreatePageNumValue(sal_uInt16 nNum) const;
DocumentType GetDocumentType() const { return meDocType; }
- void SetAllocDocSh(BOOL bAlloc);
+ void SetAllocDocSh(sal_Bool bAlloc);
void CreatingDataObj( SdTransferable* pTransferable ) { mpCreatingTransferable = pTransferable; }
@@ -257,25 +257,25 @@ public:
for newly created slides.
*/
SD_DLLPUBLIC void CreateFirstPages( SdDrawDocument* pRefDocument = 0 );
- SD_DLLPUBLIC BOOL CreateMissingNotesAndHandoutPages();
+ SD_DLLPUBLIC sal_Bool CreateMissingNotesAndHandoutPages();
- void MovePage(USHORT nPgNum, USHORT nNewPos);
- void InsertPage(SdrPage* pPage, USHORT nPos=0xFFFF);
- void DeletePage(USHORT nPgNum);
- SdrPage* RemovePage(USHORT nPgNum);
+ void MovePage(sal_uInt16 nPgNum, sal_uInt16 nNewPos);
+ void InsertPage(SdrPage* pPage, sal_uInt16 nPos=0xFFFF);
+ void DeletePage(sal_uInt16 nPgNum);
+ SdrPage* RemovePage(sal_uInt16 nPgNum);
- virtual void InsertMasterPage(SdrPage* pPage, USHORT nPos=0xFFFF);
- virtual SdrPage* RemoveMasterPage(USHORT nPgNum);
+ virtual void InsertMasterPage(SdrPage* pPage, sal_uInt16 nPos=0xFFFF);
+ virtual SdrPage* RemoveMasterPage(sal_uInt16 nPgNum);
- void RemoveUnnecessaryMasterPages( SdPage* pMaster=NULL, BOOL bOnlyDuplicatePages=FALSE, BOOL bUndo=TRUE );
- SD_DLLPUBLIC void SetMasterPage(USHORT nSdPageNum, const String& rLayoutName,
- SdDrawDocument* pSourceDoc, BOOL bMaster, BOOL bCheckMasters);
+ void RemoveUnnecessaryMasterPages( SdPage* pMaster=NULL, sal_Bool bOnlyDuplicatePages=sal_False, sal_Bool bUndo=sal_True );
+ SD_DLLPUBLIC void SetMasterPage(sal_uInt16 nSdPageNum, const String& rLayoutName,
+ SdDrawDocument* pSourceDoc, sal_Bool bMaster, sal_Bool bCheckMasters);
SD_DLLPUBLIC SdDrawDocument* OpenBookmarkDoc(const String& rBookmarkFile);
SdDrawDocument* OpenBookmarkDoc(SfxMedium& rMedium);
- BOOL InsertBookmark(List* pBookmarkList, List* pExchangeList, BOOL bLink,
- BOOL bReplace, USHORT nPgPos, BOOL bNoDialogs,
- ::sd::DrawDocShell* pBookmarkDocSh, BOOL bCopy,
+ sal_Bool InsertBookmark(List* pBookmarkList, List* pExchangeList, sal_Bool bLink,
+ sal_Bool bReplace, sal_uInt16 nPgPos, sal_Bool bNoDialogs,
+ ::sd::DrawDocShell* pBookmarkDocSh, sal_Bool bCopy,
Point* pObjPos);
bool IsStartWithPresentation() const;
@@ -289,7 +289,7 @@ public:
@attention Beware! This method in it's current state does not
handle all combinations of their input parameters
- correctly. For example, for pBookmarkList=NULL, bReplace=TRUE
+ correctly. For example, for pBookmarkList=NULL, bReplace=sal_True
is ignored (no replace happens).
@param pBookmarkList
@@ -326,16 +326,16 @@ public:
Whether the replace operation should take the name from the new
page, or preserve the old name
*/
- BOOL InsertBookmarkAsPage(List* pBookmarkList, List* pExchangeList,
- BOOL bLink, BOOL bReplace, USHORT nPgPos,
- BOOL bNoDialogs, ::sd::DrawDocShell* pBookmarkDocSh,
- BOOL bCopy, BOOL bMergeMasterPages,
- BOOL bPreservePageNames);
- BOOL InsertBookmarkAsObject(List* pBookmarkList, List* pExchangeListL,
- BOOL bLink, ::sd::DrawDocShell* pBookmarkDocSh,
+ sal_Bool InsertBookmarkAsPage(List* pBookmarkList, List* pExchangeList,
+ sal_Bool bLink, sal_Bool bReplace, sal_uInt16 nPgPos,
+ sal_Bool bNoDialogs, ::sd::DrawDocShell* pBookmarkDocSh,
+ sal_Bool bCopy, sal_Bool bMergeMasterPages,
+ sal_Bool bPreservePageNames);
+ sal_Bool InsertBookmarkAsObject(List* pBookmarkList, List* pExchangeListL,
+ sal_Bool bLink, ::sd::DrawDocShell* pBookmarkDocSh,
Point* pObjPos);
void IterateBookmarkPages( SdDrawDocument* pBookmarkDoc, List* pBookmarkList,
- USHORT nBMSdPageCount,
+ sal_uInt16 nBMSdPageCount,
InsertBookmarkAsPage_PageFunctorBase& rPageIterator );
SD_DLLPUBLIC void CloseBookmarkDoc();
@@ -354,25 +354,25 @@ public:
Returns the index of the page with the given name or
SDRPAGE_NOTFOUND (=0xffff) when such a page does not exist.
*/
- USHORT GetPageByName(const String& rPgName, BOOL& rbIsMasterPage ) const;
- SD_DLLPUBLIC SdPage*GetSdPage(USHORT nPgNum, PageKind ePgKind) const;
- SD_DLLPUBLIC USHORT GetSdPageCount(PageKind ePgKind) const;
+ sal_uInt16 GetPageByName(const String& rPgName, sal_Bool& rbIsMasterPage ) const;
+ SD_DLLPUBLIC SdPage*GetSdPage(sal_uInt16 nPgNum, PageKind ePgKind) const;
+ SD_DLLPUBLIC sal_uInt16 GetSdPageCount(PageKind ePgKind) const;
- void SetSelected(SdPage* pPage, BOOL bSelect);
- BOOL MovePages(USHORT nTargetPage);
+ void SetSelected(SdPage* pPage, sal_Bool bSelect);
+ sal_Bool MovePages(sal_uInt16 nTargetPage);
- SD_DLLPUBLIC SdPage*GetMasterSdPage(USHORT nPgNum, PageKind ePgKind);
- SD_DLLPUBLIC USHORT GetMasterSdPageCount(PageKind ePgKind) const;
+ SD_DLLPUBLIC SdPage*GetMasterSdPage(sal_uInt16 nPgNum, PageKind ePgKind);
+ SD_DLLPUBLIC sal_uInt16 GetMasterSdPageCount(PageKind ePgKind) const;
- USHORT GetMasterPageUserCount(SdrPage* pMaster) const;
+ sal_uInt16 GetMasterPageUserCount(SdrPage* pMaster) const;
const sd::PresentationSettings& getPresentationSettings() const { return maPresentationSettings; }
sd::PresentationSettings& getPresentationSettings() { return maPresentationSettings; }
const ::com::sun::star::uno::Reference< ::com::sun::star::presentation::XPresentation2 >& getPresentation() const;
- void SetSummationOfParagraphs( BOOL bOn = TRUE ) { mbSummationOfParagraphs = bOn; }
- BOOL IsSummationOfParagraphs() const { return mbSummationOfParagraphs; }
+ void SetSummationOfParagraphs( sal_Bool bOn = sal_True ) { mbSummationOfParagraphs = bOn; }
+ sal_Bool IsSummationOfParagraphs() const { return mbSummationOfParagraphs; }
/** Set the mode that controls whether (and later how) the formatting of the document
depends on the current printer metrics.
@@ -396,20 +396,20 @@ public:
*/
sal_Int32 GetPrinterIndependentLayout (void);
- void SetOnlineSpell( BOOL bIn );
- BOOL GetOnlineSpell() const { return mbOnlineSpell; }
+ void SetOnlineSpell( sal_Bool bIn );
+ sal_Bool GetOnlineSpell() const { return mbOnlineSpell; }
void StopOnlineSpelling();
- void StartOnlineSpelling(BOOL bForceSpelling=TRUE);
+ void StartOnlineSpelling(sal_Bool bForceSpelling=sal_True);
void ImpOnlineSpellCallback(SpellCallbackInfo* pInfo, SdrObject* pObj, SdrOutliner* pOutl);
void InsertObject(SdrObject* pObj, SdPage* pPage);
void RemoveObject(SdrObject* pObj, SdPage* pPage);
- ULONG GetLinkCount();
+ sal_uLong GetLinkCount();
List* GetFrameViewList() const { return mpFrameViewList; }
- SD_DLLPUBLIC List* GetCustomShowList(BOOL bCreate = FALSE);
+ SD_DLLPUBLIC List* GetCustomShowList(sal_Bool bCreate = sal_False);
void NbcSetChanged(sal_Bool bFlag = sal_True);
@@ -424,9 +424,9 @@ public:
void NewOrLoadCompleted(DocCreationMode eMode);
void NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool );
- BOOL IsNewOrLoadCompleted() const {return mbNewOrLoadCompleted; }
+ sal_Bool IsNewOrLoadCompleted() const {return mbNewOrLoadCompleted; }
- ::sd::FrameView* GetFrameView(ULONG nPos) {
+ ::sd::FrameView* GetFrameView(sal_uLong nPos) {
return static_cast< ::sd::FrameView*>(
mpFrameViewList->GetObject(nPos));}
@@ -447,10 +447,10 @@ public:
void CheckMasterPages();
void Merge(SdrModel& rSourceModel,
- USHORT nFirstPageNum=0, USHORT nLastPageNum=0xFFFF,
- USHORT nDestPos=0xFFFF,
- FASTBOOL bMergeMasterPages=FALSE, FASTBOOL bAllMasterPages=FALSE,
- FASTBOOL bUndo=TRUE, FASTBOOL bTreadSourceAsConst=FALSE);
+ sal_uInt16 nFirstPageNum=0, sal_uInt16 nLastPageNum=0xFFFF,
+ sal_uInt16 nDestPos=0xFFFF,
+ FASTBOOL bMergeMasterPages=sal_False, FASTBOOL bAllMasterPages=sal_False,
+ FASTBOOL bUndo=sal_True, FASTBOOL bTreadSourceAsConst=sal_False);
SD_DLLPUBLIC ::com::sun::star::text::WritingMode GetDefaultWritingMode() const;
void SetDefaultWritingMode( ::com::sun::star::text::WritingMode eMode );
@@ -501,15 +501,15 @@ public:
Returns an index of the inserted pages that can be used with the
<member>GetSdPage()</member> method.
*/
- USHORT CreatePage (
+ sal_uInt16 CreatePage (
SdPage* pCurrentPage,
PageKind ePageKind,
const String& sStandardPageName,
const String& sNotesPageName,
AutoLayout eStandardLayout,
AutoLayout eNotesLayout,
- BOOL bIsPageBack,
- BOOL bIsPageObj,
+ sal_Bool bIsPageBack,
+ sal_Bool bIsPageObj,
const sal_Int32 nInsertPosition = -1);
/** This method acts as a simplified front end for the more complex
@@ -522,7 +522,7 @@ public:
Returns an index of the inserted pages that can be used with the
<member>GetSdPage()</member> method.
*/
- USHORT DuplicatePage (USHORT nPageNum);
+ sal_uInt16 DuplicatePage (sal_uInt16 nPageNum);
/** Create and insert a set of two new pages that are copies of the
given <argument>pCurrentPage</argument> and its associated notes
@@ -561,15 +561,15 @@ public:
Returns an index of the inserted pages that can be used with the
<member>GetSdPage()</member> method.
*/
- USHORT DuplicatePage (
+ sal_uInt16 DuplicatePage (
SdPage* pCurrentPage,
PageKind ePageKind,
const String& sStandardPageName,
const String& sNotesPageName,
AutoLayout eStandardLayout,
AutoLayout eNotesLayout,
- BOOL bIsPageBack,
- BOOL bIsPageObj,
+ sal_Bool bIsPageBack,
+ sal_Bool bIsPageObj,
const sal_Int32 nInsertPosition = -1);
/** return the document fonts for latin, cjk and ctl according to the current
@@ -636,15 +636,15 @@ private:
Returns an index of the inserted pages that can be used with the
<member>GetSdPage()</member> method.
*/
- USHORT InsertPageSet (
+ sal_uInt16 InsertPageSet (
SdPage* pCurrentPage,
PageKind ePageKind,
const String& sStandardPageName,
const String& sNotesPageName,
AutoLayout eStandardLayout,
AutoLayout eNotesLayout,
- BOOL bIsPageBack,
- BOOL bIsPageObj,
+ sal_Bool bIsPageBack,
+ sal_Bool bIsPageObj,
SdPage* pStandardPage,
SdPage* pNotesPage,
sal_Int32 nInsertPosition = -1);
@@ -668,9 +668,9 @@ private:
SdPage* pPreviousPage,
SdPage* pPage,
const String& sPageName,
- USHORT nInsertionPoint,
- BOOL bIsPageBack,
- BOOL bIsPageObj);
+ sal_uInt16 nInsertionPoint,
+ sal_Bool bIsPageBack,
+ sal_Bool bIsPageObj);
// #109538#
virtual void PageListChanged();
@@ -693,8 +693,8 @@ private:
DrawDocShell* mpDocShell;
SdDrawDocument* mpDoc;
- BOOL mbIsEnableSetModified;
- BOOL mbIsDocumentChanged;
+ sal_Bool mbIsEnableSetModified;
+ sal_Bool mbIsDocumentChanged;
};
}
diff --git a/sd/inc/glob.hxx b/sd/inc/glob.hxx
index 278aef490fdb..096ea4372626 100755
--- a/sd/inc/glob.hxx
+++ b/sd/inc/glob.hxx
@@ -70,10 +70,10 @@
#define SD_IF_SDTOOLPANELSHELL SFX_INTERFACE_SD_START + 30
// Inventor-Id fuer StarDraw UserData
-const UINT32 SdUDInventor=UINT32('S')*0x00000001+
- UINT32('D')*0x00000100+
- UINT32('U')*0x00010000+
- UINT32('D')*0x01000000;
+const sal_uInt32 SdUDInventor=sal_uInt32('S')*0x00000001+
+ sal_uInt32('D')*0x00000100+
+ sal_uInt32('U')*0x00010000+
+ sal_uInt32('D')*0x01000000;
// Object-Ids fuer StarDraw UserData
#define SD_ANIMATIONINFO_ID 1
diff --git a/sd/inc/pch/precompiled_sd.hxx b/sd/inc/pch/precompiled_sd.hxx
index 2a80030b7560..2a4cec779f64 100755
--- a/sd/inc/pch/precompiled_sd.hxx
+++ b/sd/inc/pch/precompiled_sd.hxx
@@ -530,7 +530,6 @@
#include "unotools/pathoptions.hxx"
#include "svl/poolitem.hxx"
#include "svtools/prgsbar.hxx"
-#include "svtools/printdlg.hxx"
#include "svl/ptitem.hxx"
#include "svl/rectitem.hxx"
#include "unotools/saveopt.hxx"
@@ -901,7 +900,7 @@
#include "vcl/virdev.hxx"
#include "vcl/waitobj.hxx"
#include "vcl/window.hxx"
-#include "vcl/wintypes.hxx"
+#include "tools/wintypes.hxx"
#include "vcl/wrkwin.hxx"
#include "vos/diagnose.hxx"
diff --git a/sd/inc/sdabstdlg.hxx b/sd/inc/sdabstdlg.hxx
index 1b47afea90ae..555f9d5a3a7e 100755
--- a/sd/inc/sdabstdlg.hxx
+++ b/sd/inc/sdabstdlg.hxx
@@ -80,8 +80,8 @@ public:
class AbstractSdCustomShowDlg : public VclAbstractDialog //add for SdCustomShowDlg
{
public:
- virtual BOOL IsModified() const = 0;
- virtual BOOL IsCustomShow() const = 0;
+ virtual sal_Bool IsModified() const = 0;
+ virtual sal_Bool IsCustomShow() const = 0;
};
class AbstractAssistentDlg : public VclAbstractDialog //add for AssistentDlg
@@ -89,11 +89,11 @@ class AbstractAssistentDlg : public VclAbstractDialog //add for AssistentDlg
public:
virtual SfxObjectShellLock GetDocument() = 0;
virtual OutputType GetOutputMedium() const = 0;
- virtual BOOL IsSummary() const = 0;
+ virtual sal_Bool IsSummary() const = 0;
virtual StartType GetStartType() const = 0;
virtual String GetDocPath() const = 0;
- virtual BOOL GetStartWithFlag() const = 0;
- virtual BOOL IsDocEmpty() const = 0;
+ virtual sal_Bool GetStartWithFlag() const = 0;
+ virtual sal_Bool IsDocEmpty() const = 0;
virtual String GetPassword() = 0;
};
@@ -110,7 +110,7 @@ public:
virtual void GetAttr(SfxItemSet& rOutAttrs) = 0;
virtual void HideRadioGroup() = 0;
virtual void HideDeleteBtn() = 0;
- virtual void SetInputFields(BOOL bEnableX, BOOL bEnableY) = 0;
+ virtual void SetInputFields(sal_Bool bEnableX, sal_Bool bEnableY) = 0;
//from class ::Window
virtual void SetText( const XubString& rStr ) = 0;
};
@@ -126,25 +126,25 @@ public:
class AbstractSdInsertPasteDlg : public VclAbstractDialog //add for SdInsertPasteDlg
{
public:
- virtual BOOL IsInsertBefore() const = 0;
+ virtual sal_Bool IsInsertBefore() const = 0;
};
class AbstractSdInsertPagesObjsDlg : public VclAbstractDialog //add for SdInsertPagesObjsDlg
{
public:
virtual ::Window* GetWindow() = 0; //this method is added for return a ::Window type pointer
- virtual List* GetList( USHORT nType ) = 0;
- virtual BOOL IsLink() = 0;
- virtual BOOL IsRemoveUnnessesaryMasterPages() const = 0;
+ virtual List* GetList( sal_uInt16 nType ) = 0;
+ virtual sal_Bool IsLink() = 0;
+ virtual sal_Bool IsRemoveUnnessesaryMasterPages() const = 0;
};
class AbstractMorphDlg : public VclAbstractDialog //add for MorphDlg
{
public:
virtual void SaveSettings() const = 0;
- virtual USHORT GetFadeSteps() const = 0;
- virtual BOOL IsAttributeFade() const = 0;
- virtual BOOL IsOrientationFade() const = 0;
+ virtual sal_uInt16 GetFadeSteps() const = 0;
+ virtual sal_Bool IsAttributeFade() const = 0;
+ virtual sal_Bool IsOrientationFade() const = 0;
};
class AbstractSdStartPresDlg : public VclAbstractDialog //add for SdStartPresentationDlg
@@ -185,12 +185,12 @@ class SdAbstractDialogFactory
public:
static SdAbstractDialogFactory* Create();
- virtual VclAbstractDialog* CreateBreakDlg(::Window* pWindow, ::sd::DrawView* pDrView, ::sd::DrawDocShell* pShell, ULONG nSumActionCount, ULONG nObjCount ) = 0;
+ virtual VclAbstractDialog* CreateBreakDlg(::Window* pWindow, ::sd::DrawView* pDrView, ::sd::DrawDocShell* pShell, sal_uLong nSumActionCount, sal_uLong nObjCount ) = 0;
virtual AbstractCopyDlg* CreateCopyDlg( ::Window* pWindow, const SfxItemSet& rInAttrs, XColorTable* pColTab, ::sd::View* pView ) = 0;
virtual AbstractSdCustomShowDlg* CreateSdCustomShowDlg( ::Window* pWindow, SdDrawDocument& rDrawDoc ) = 0;
virtual SfxAbstractTabDialog* CreateSdTabCharDialog( ::Window* pParent, const SfxItemSet* pAttr, SfxObjectShell* pDocShell ) = 0;
- virtual SfxAbstractTabDialog* CreateSdTabPageDialog( ::Window* pParent, const SfxItemSet* pAttr, SfxObjectShell* pDocShell, BOOL bAreaPage = TRUE ) = 0;
- virtual AbstractAssistentDlg* CreateAssistentDlg( ::Window* pParent, BOOL bAutoPilot) = 0;
+ virtual SfxAbstractTabDialog* CreateSdTabPageDialog( ::Window* pParent, const SfxItemSet* pAttr, SfxObjectShell* pDocShell, sal_Bool bAreaPage = sal_True ) = 0;
+ virtual AbstractAssistentDlg* CreateAssistentDlg( ::Window* pParent, sal_Bool bAutoPilot) = 0;
virtual AbstractSdModifyFieldDlg* CreateSdModifyFieldDlg( ::Window* pWindow, const SvxFieldData* pInField, const SfxItemSet& rSet ) = 0;
virtual AbstractSdSnapLineDlg* CreateSdSnapLineDlg( ::Window* pWindow, const SfxItemSet& rInAttrs, ::sd::View* pView) = 0;
virtual AbstractSdInsertLayerDlg* CreateSdInsertLayerDlg( ::Window* pWindow, const SfxItemSet& rInAttrs, bool bDeletable, String aStr ) = 0;
diff --git a/sd/inc/sdattr.hxx b/sd/inc/sdattr.hxx
index 85e231f0a357..7d44c1d039b0 100644..100755
--- a/sd/inc/sdattr.hxx
+++ b/sd/inc/sdattr.hxx
@@ -80,7 +80,7 @@ public:
class SdAttrLayerVisible : public SfxBoolItem
{
public:
- SdAttrLayerVisible( BOOL bValue = TRUE ) :
+ SdAttrLayerVisible( sal_Bool bValue = sal_True ) :
SfxBoolItem( ATTR_LAYER_VISIBLE, bValue ) {}
};
@@ -89,7 +89,7 @@ public:
class SdAttrLayerPrintable : public SfxBoolItem
{
public:
- SdAttrLayerPrintable( BOOL bValue = TRUE ) :
+ SdAttrLayerPrintable( sal_Bool bValue = sal_True ) :
SfxBoolItem( ATTR_LAYER_PRINTABLE, bValue ) {}
};
@@ -98,7 +98,7 @@ public:
class SdAttrLayerLocked : public SfxBoolItem
{
public:
- SdAttrLayerLocked( BOOL bValue = FALSE ) :
+ SdAttrLayerLocked( sal_Bool bValue = sal_False ) :
SfxBoolItem( ATTR_LAYER_LOCKED, bValue ) {}
};
@@ -107,7 +107,7 @@ public:
class SdAttrLayerThisPage : public SfxBoolItem
{
public:
- SdAttrLayerThisPage( BOOL bValue = FALSE ) :
+ SdAttrLayerThisPage( sal_Bool bValue = sal_False ) :
SfxBoolItem( ATTR_LAYER_THISPAGE, bValue ) {}
};
@@ -121,8 +121,8 @@ public:
DiaEffectItem( SvStream& rIn );
virtual SfxPoolItem* Clone( SfxItemPool* pPool = 0 ) const;
- virtual SfxPoolItem* Create( SvStream& rIn, USHORT nVer ) const;
- USHORT GetValueCount() const { return FADE_EFFECT_COUNT; }
+ virtual SfxPoolItem* Create( SvStream& rIn, sal_uInt16 nVer ) const;
+ sal_uInt16 GetValueCount() const { return FADE_EFFECT_COUNT; }
::com::sun::star::presentation::FadeEffect GetValue() const
{ return (::com::sun::star::presentation::FadeEffect) SfxEnumItem::GetValue(); }
};
@@ -137,8 +137,8 @@ public:
DiaSpeedItem( SvStream& rIn );
virtual SfxPoolItem* Clone( SfxItemPool* pPool = 0 ) const;
- virtual SfxPoolItem* Create( SvStream& rIn, USHORT nVer ) const;
- USHORT GetValueCount() const { return FADE_SPEED_COUNT; }
+ virtual SfxPoolItem* Create( SvStream& rIn, sal_uInt16 nVer ) const;
+ sal_uInt16 GetValueCount() const { return FADE_SPEED_COUNT; }
FadeSpeed GetValue() const
{ return (FadeSpeed) SfxEnumItem::GetValue(); }
};
@@ -153,8 +153,8 @@ public:
DiaAutoItem( SvStream& rIn );
virtual SfxPoolItem* Clone( SfxItemPool* pPool = 0 ) const;
- virtual SfxPoolItem* Create( SvStream& rIn, USHORT nVer ) const;
- USHORT GetValueCount() const { return PRESCHANGE_COUNT; }
+ virtual SfxPoolItem* Create( SvStream& rIn, sal_uInt16 nVer ) const;
+ sal_uInt16 GetValueCount() const { return PRESCHANGE_COUNT; }
PresChange GetValue() const { return (PresChange) SfxEnumItem::GetValue(); }
};
@@ -164,7 +164,7 @@ class DiaTimeItem : public SfxUInt32Item
{
public:
TYPEINFO();
- DiaTimeItem( UINT32 nValue = 0L );
+ DiaTimeItem( sal_uInt32 nValue = 0L );
virtual SfxPoolItem* Clone( SfxItemPool* pPool = 0 ) const;
virtual int operator==( const SfxPoolItem& ) const;
diff --git a/sd/inc/sderror.hxx b/sd/inc/sderror.hxx
index 2564584cb3eb..daceb72226c3 100644..100755
--- a/sd/inc/sderror.hxx
+++ b/sd/inc/sderror.hxx
@@ -49,12 +49,12 @@
#ifndef __RSC
-inline FASTBOOL IsWarning( ULONG nErr )
+inline FASTBOOL IsWarning( sal_uLong nErr )
{
return 0 != ( nErr & ERRCODE_WARNING_MASK & nErr );
}
-inline FASTBOOL IsError( ULONG nErr )
+inline FASTBOOL IsError( sal_uLong nErr )
{
return nErr && 0 == ( ERRCODE_WARNING_MASK & nErr );
}
diff --git a/sd/inc/sdgrffilter.hxx b/sd/inc/sdgrffilter.hxx
index 7d4ef3ab9a3b..48f16f3dc4ec 100644..100755
--- a/sd/inc/sdgrffilter.hxx
+++ b/sd/inc/sdgrffilter.hxx
@@ -50,7 +50,7 @@ public:
sal_Bool Export();
static void SaveGraphic( const ::com::sun::star::uno::Reference< ::com::sun::star::drawing::XShape >& xShape );
- static void HandleGraphicFilterError( USHORT nFilterError, ULONG nStreamError = ERRCODE_NONE );
+ static void HandleGraphicFilterError( sal_uInt16 nFilterError, sal_uLong nStreamError = ERRCODE_NONE );
};
#endif // _SD_SDGRFFILTER_HXX
diff --git a/sd/inc/sdhtmlfilter.hxx b/sd/inc/sdhtmlfilter.hxx
index 9b1a11d839a3..53c447c5fc08 100644..100755
--- a/sd/inc/sdhtmlfilter.hxx
+++ b/sd/inc/sdhtmlfilter.hxx
@@ -47,7 +47,7 @@ public:
virtual sal_Bool Export();
private:
- DECL_LINK( IOProgressHdl, USHORT* );
+ DECL_LINK( IOProgressHdl, sal_uInt16* );
};
diff --git a/sd/inc/sdiocmpt.hxx b/sd/inc/sdiocmpt.hxx
index d2724b99ec75..4c8396e63cd7 100644..100755
--- a/sd/inc/sdiocmpt.hxx
+++ b/sd/inc/sdiocmpt.hxx
@@ -37,17 +37,17 @@ class old_SdrDownCompat
{
protected:
SvStream& rStream;
- UINT32 nSubRecSiz;
- UINT32 nSubRecPos;
- UINT16 nMode;
- BOOL bOpen;
+ sal_uInt32 nSubRecSiz;
+ sal_uInt32 nSubRecPos;
+ sal_uInt16 nMode;
+ sal_Bool bOpen;
protected:
void Read();
void Write();
public:
- old_SdrDownCompat(SvStream& rNewStream, UINT16 nNewMode);
+ old_SdrDownCompat(SvStream& rNewStream, sal_uInt16 nNewMode);
~old_SdrDownCompat();
void OpenSubRecord();
void CloseSubRecord();
@@ -55,20 +55,20 @@ public:
//////////////////////////////////////////////////////////////////////////////
#include "sddllapi.h"
-#define SDIOCOMPAT_VERSIONDONTKNOW (UINT16)0xffff
+#define SDIOCOMPAT_VERSIONDONTKNOW (sal_uInt16)0xffff
class SD_DLLPUBLIC SdIOCompat : public old_SdrDownCompat
{
private:
- UINT16 nVersion;
+ sal_uInt16 nVersion;
public:
// nNewMode: STREAM_READ oder STREAM_WRITE
// nVer: nur beim Schreiben angeben
- SdIOCompat(SvStream& rNewStream, USHORT nNewMode,
- UINT16 nVer = SDIOCOMPAT_VERSIONDONTKNOW);
+ SdIOCompat(SvStream& rNewStream, sal_uInt16 nNewMode,
+ sal_uInt16 nVer = SDIOCOMPAT_VERSIONDONTKNOW);
~SdIOCompat();
- UINT16 GetVersion() const { return nVersion; }
+ sal_uInt16 GetVersion() const { return nVersion; }
};
#endif // _SD_SDIOCMPT_HXX
diff --git a/sd/inc/sdmod.hxx b/sd/inc/sdmod.hxx
index c323f9678d38..ef673fdea0c7 100755
--- a/sd/inc/sdmod.hxx
+++ b/sd/inc/sdmod.hxx
@@ -117,8 +117,8 @@ public:
SdOptions* GetSdOptions(DocumentType eDocType);
SD_DLLPUBLIC SvStorageStreamRef GetOptionStream( const String& rOptionName, SdOptionStreamMode eMode );
- BOOL GetWaterCan() const { return bWaterCan; }
- void SetWaterCan( BOOL bWC ) { bWaterCan = bWC; }
+ sal_Bool GetWaterCan() const { return bWaterCan; }
+ void SetWaterCan( sal_Bool bWC ) { bWaterCan = bWC; }
SvxSearchItem* GetSearchItem() { return (pSearchItem); }
void SetSearchItem(SvxSearchItem* pItem) { pSearchItem = pItem; }
@@ -140,9 +140,9 @@ public:
SD_DLLPUBLIC SvNumberFormatter* GetNumberFormatter();
//virtuelle Methoden fuer den Optionendialog
- virtual SfxItemSet* CreateItemSet( USHORT nId );
- virtual void ApplyItemSet( USHORT nId, const SfxItemSet& rSet );
- virtual SfxTabPage* CreateTabPage( USHORT nId, Window* pParent, const SfxItemSet& rSet );
+ virtual SfxItemSet* CreateItemSet( sal_uInt16 nId );
+ virtual void ApplyItemSet( sal_uInt16 nId, const SfxItemSet& rSet );
+ virtual SfxTabPage* CreateTabPage( sal_uInt16 nId, Window* pParent, const SfxItemSet& rSet );
protected:
@@ -151,8 +151,8 @@ protected:
SvxSearchItem* pSearchItem;
SvNumberFormatter* pNumberFormatter;
SvStorageRef xOptionStorage;
- BOOL bAutoSave;
- BOOL bWaterCan;
+ sal_Bool bAutoSave;
+ sal_Bool bWaterCan;
SfxErrorHandler* mpErrorHdl;
/** This device is used for printer independent layout. It is virtual
in the sense that it does not represent a printer. The pointer may
diff --git a/sd/inc/sdresid.hxx b/sd/inc/sdresid.hxx
index db41ccdb689c..04e6d0dc0724 100644..100755
--- a/sd/inc/sdresid.hxx
+++ b/sd/inc/sdresid.hxx
@@ -36,7 +36,7 @@
class SD_DLLPUBLIC SdResId : public ResId
{
public:
- SdResId(USHORT nId);
+ SdResId(sal_uInt16 nId);
};
#endif /* _SD_SDRESID_HXX */
diff --git a/sd/inc/sdxmlwrp.hxx b/sd/inc/sdxmlwrp.hxx
index 00532c1a142d..207cffed90ae 100644..100755
--- a/sd/inc/sdxmlwrp.hxx
+++ b/sd/inc/sdxmlwrp.hxx
@@ -49,7 +49,7 @@ public:
::sd::DrawDocShell& rDocShell,
sal_Bool bShowProgress,
SdXMLFilterMode eFilterMode = SDXMLMODE_Normal,
- ULONG nStoreVer = SOFFICE_FILEFORMAT_8 );
+ sal_uLong nStoreVer = SOFFICE_FILEFORMAT_8 );
virtual ~SdXMLFilter (void);
sal_Bool Import( ErrCode& nError );
@@ -57,7 +57,7 @@ public:
private:
SdXMLFilterMode meFilterMode;
- ULONG mnStoreVer;
+ sal_uLong mnStoreVer;
};
#endif // _SDXMLWRP_HXX
diff --git a/sd/inc/stlpool.hxx b/sd/inc/stlpool.hxx
index fd9dbeae5977..4f33b360d4f6 100755
--- a/sd/inc/stlpool.hxx
+++ b/sd/inc/stlpool.hxx
@@ -129,7 +129,7 @@ public:
protected:
void CopySheets(SdStyleSheetPool& rSourcePool, SfxStyleFamily eFamily );
- virtual SfxStyleSheetBase* Create(const String& rName, SfxStyleFamily eFamily, USHORT nMask);
+ virtual SfxStyleSheetBase* Create(const String& rName, SfxStyleFamily eFamily, sal_uInt16 nMask);
virtual SfxStyleSheetBase* Create(const SdStyleSheet& rStyle);
using SfxStyleSheetPool::Create;
diff --git a/sd/inc/stlsheet.hxx b/sd/inc/stlsheet.hxx
index 138b06ae077d..0029b2d3c49e 100644..100755
--- a/sd/inc/stlsheet.hxx
+++ b/sd/inc/stlsheet.hxx
@@ -59,19 +59,19 @@ typedef cppu::ImplInheritanceHelper5< SfxUnoStyleSheet,
class SdStyleSheet : public SdStyleSheetBase, private ::cppu::BaseMutex
{
public:
- SdStyleSheet( const rtl::OUString& rDisplayName, SfxStyleSheetBasePool& rPool, SfxStyleFamily eFamily, USHORT nMask );
+ SdStyleSheet( const rtl::OUString& rDisplayName, SfxStyleSheetBasePool& rPool, SfxStyleFamily eFamily, sal_uInt16 nMask );
SdStyleSheet( const SdStyleSheet& );
- virtual BOOL SetParent (const String& rParentName);
+ virtual sal_Bool SetParent (const String& rParentName);
virtual SfxItemSet& GetItemSet();
- virtual BOOL IsUsed() const;
- virtual BOOL HasFollowSupport() const;
- virtual BOOL HasParentSupport() const;
- virtual BOOL HasClearParentSupport() const;
- virtual BOOL SetName( const UniString& );
- virtual void SetHelpId( const String& r, ULONG nId );
+ virtual sal_Bool IsUsed() const;
+ virtual sal_Bool HasFollowSupport() const;
+ virtual sal_Bool HasParentSupport() const;
+ virtual sal_Bool HasClearParentSupport() const;
+ virtual sal_Bool SetName( const UniString& );
+ virtual void SetHelpId( const String& r, sal_uLong nId );
- void AdjustToFontHeight(SfxItemSet& rSet, BOOL bOnlyMissingItems = TRUE);
+ void AdjustToFontHeight(SfxItemSet& rSet, sal_Bool bOnlyMissingItems = sal_True);
SdStyleSheet* GetRealStyleSheet() const;
SdStyleSheet* GetPseudoStyleSheet() const;
@@ -130,7 +130,7 @@ public:
protected:
const SfxItemPropertySimpleEntry* getPropertyMapEntry( const ::rtl::OUString& rPropertyName ) const throw();
- virtual void Load (SvStream& rIn, USHORT nVersion);
+ virtual void Load (SvStream& rIn, sal_uInt16 nVersion);
virtual void Store(SvStream& rOut);
virtual void Notify(SfxBroadcaster& rBC, const SfxHint& rHint);
diff --git a/sd/inc/undo/undomanager.hxx b/sd/inc/undo/undomanager.hxx
index b2e40c1e7442..22167d9636fc 100644..100755
--- a/sd/inc/undo/undomanager.hxx
+++ b/sd/inc/undo/undomanager.hxx
@@ -37,34 +37,24 @@ namespace sd
class UndoManager : public SfxUndoManager
{
public:
- UndoManager( USHORT nMaxUndoActionCount = 20 );
+ UndoManager( sal_uInt16 nMaxUndoActionCount = 20 );
- virtual void EnterListAction(const UniString &rComment, const UniString& rRepeatComment, USHORT nId=0);
- virtual void LeaveListAction();
+ virtual void EnterListAction(const UniString &rComment, const UniString& rRepeatComment, sal_uInt16 nId=0);
- virtual void AddUndoAction( SfxUndoAction *pAction, BOOL bTryMerg=FALSE );
-
- bool isInListAction() const { return mnListLevel != 0; }
- bool isInUndo() const { return maIsInUndoLock.isLocked(); }
-
- virtual BOOL Undo( USHORT nCount=1 );
- virtual BOOL Redo( USHORT nCount=1 );
+ virtual void AddUndoAction( SfxUndoAction *pAction, sal_Bool bTryMerg=sal_False );
/** Set or reset the undo manager linked with the called undo manager.
*/
- void SetLinkedUndoManager (SfxUndoManager* pLinkedUndoManager);
+ void SetLinkedUndoManager (::svl::IUndoManager* pLinkedUndoManager);
private:
using SfxUndoManager::Undo;
using SfxUndoManager::Redo;
- int mnListLevel;
- ScopeLock maIsInUndoLock;
-
/** Used when the outline view is visible as a last resort to
synchronize the undo managers.
*/
- SfxUndoManager* mpLinkedUndoManager;
+ ::svl::IUndoManager* mpLinkedUndoManager;
/** Call ClearRedo() at the linked undo manager, when present.
diff --git a/sd/inc/sdpage.hxx b/sd/inc/sdpage.hxx
index e4125051c526..8bc342b2bc89 100755
--- a/sd/inc/sdpage.hxx
+++ b/sd/inc/sdpage.hxx
@@ -129,12 +129,12 @@ protected:
AutoLayout meAutoLayout; // AutoLayout
sd::ShapeList maPresentationShapeList; // Praesentationsobjekte
sd::ScopeLock maLockAutoLayoutArrangement;
- BOOL mbSelected; // Selektionskennung
+ sal_Bool mbSelected; // Selektionskennung
PresChange mePresChange; // manuell/automatisch/halbautomatisch
- UINT32 mnTime; // Anzeigedauer in Sekunden
- BOOL mbSoundOn; // mit/ohne Sound (TRUE/FALSE)
- BOOL mbExcluded; // wird in der Show nicht/doch
- // angezeigt (TRUE/FALSE)
+ sal_uInt32 mnTime; // Anzeigedauer in Sekunden
+ sal_Bool mbSoundOn; // mit/ohne Sound (sal_True/sal_False)
+ sal_Bool mbExcluded; // wird in der Show nicht/doch
+ // angezeigt (sal_True/sal_False)
String maLayoutName; // Name des Layouts
String maSoundFile; // Pfad zum Soundfile (MSDOS-Notation)
bool mbLoopSound;
@@ -142,10 +142,10 @@ protected:
String maCreatedPageName; // von GetPageName erzeugter Seitenname
String maFileName; // Filename
String maBookmarkName; // Bookmarkname
- BOOL mbScaleObjects; // Objekte sollen skaliert werden
- BOOL mbBackgroundFullSize; // Hintergrundobjekt auf ganze Seite darstellen
+ sal_Bool mbScaleObjects; // Objekte sollen skaliert werden
+ sal_Bool mbBackgroundFullSize; // Hintergrundobjekt auf ganze Seite darstellen
rtl_TextEncoding meCharSet; // Text-Encoding
- USHORT mnPaperBin; // PaperBin
+ sal_uInt16 mnPaperBin; // PaperBin
Orientation meOrientation; // Print-Orientation
SdPageLink* mpPageLink; // PageLink (nur bei gelinkten Seiten)
@@ -175,25 +175,25 @@ protected:
public:
TYPEINFO();
- SdPage(SdDrawDocument& rNewDoc, StarBASIC* pBasic, BOOL bMasterPage=FALSE);
+ SdPage(SdDrawDocument& rNewDoc, StarBASIC* pBasic, sal_Bool bMasterPage=sal_False);
SdPage(const SdPage& rSrcPage);
~SdPage();
virtual SdrPage* Clone() const;
virtual SdrPage* Clone(SdrModel* pNewModel) const;
virtual void SetSize(const Size& aSize);
- virtual void SetBorder(INT32 nLft, INT32 nUpp, INT32 nRgt, INT32 Lwr);
- virtual void SetLftBorder(INT32 nBorder);
- virtual void SetRgtBorder(INT32 nBorder);
- virtual void SetUppBorder(INT32 nBorder);
- virtual void SetLwrBorder(INT32 nBorder);
+ virtual void SetBorder(sal_Int32 nLft, sal_Int32 nUpp, sal_Int32 nRgt, sal_Int32 Lwr);
+ virtual void SetLftBorder(sal_Int32 nBorder);
+ virtual void SetRgtBorder(sal_Int32 nBorder);
+ virtual void SetUppBorder(sal_Int32 nBorder);
+ virtual void SetLwrBorder(sal_Int32 nBorder);
virtual void SetModel(SdrModel* pNewModel);
virtual FASTBOOL IsReadOnly() const;
sd::ShapeList& GetPresentationShapeList() { return maPresentationShapeList; }
void EnsureMasterPageDefaultBackground();
- SdrObject* CreatePresObj(PresObjKind eObjKind, BOOL bVertical, const Rectangle& rRect, BOOL bInsert=FALSE);
+ SdrObject* CreatePresObj(PresObjKind eObjKind, sal_Bool bVertical, const Rectangle& rRect, sal_Bool bInsert=sal_False);
SdrObject* CreateDefaultPresObj(PresObjKind eObjKind, bool bInsert);
SdrObject* GetPresObj(PresObjKind eObjKind, int nIndex = 1, bool bFuzzySearch = false );
PresObjKind GetPresObjKind(SdrObject* pObj) const;
@@ -211,20 +211,20 @@ public:
/** inserts the given SdrObject into the presentation object list */
void InsertPresObj(SdrObject* pObj, PresObjKind eKind );
- void SetAutoLayout(AutoLayout eLayout, BOOL bInit=FALSE, BOOL bCreate=FALSE);
+ void SetAutoLayout(AutoLayout eLayout, sal_Bool bInit=sal_False, sal_Bool bCreate=sal_False);
AutoLayout GetAutoLayout() const { return meAutoLayout; }
- void CreateTitleAndLayout(BOOL bInit=FALSE, BOOL bCreate=FALSE);
+ void CreateTitleAndLayout(sal_Bool bInit=sal_False, sal_Bool bCreate=sal_False);
SdrObject* InsertAutoLayoutShape(SdrObject* pObj, PresObjKind eObjKind, bool bVertical, Rectangle aRect, bool bInit );
- virtual void NbcInsertObject(SdrObject* pObj, ULONG nPos=CONTAINER_APPEND,
+ virtual void NbcInsertObject(SdrObject* pObj, sal_uLong nPos=CONTAINER_APPEND,
const SdrInsertReason* pReason=NULL);
- virtual SdrObject* NbcRemoveObject(ULONG nObjNum);
- virtual SdrObject* RemoveObject(ULONG nObjNum);
+ virtual SdrObject* NbcRemoveObject(sal_uLong nObjNum);
+ virtual SdrObject* RemoveObject(sal_uLong nObjNum);
// #95876# Also overload ReplaceObject methods to realize when
// objects are removed with this mechanism instead of RemoveObject
- virtual SdrObject* NbcReplaceObject(SdrObject* pNewObj, ULONG nObjNum);
- virtual SdrObject* ReplaceObject(SdrObject* pNewObj, ULONG nObjNum);
+ virtual SdrObject* NbcReplaceObject(SdrObject* pNewObj, sal_uLong nObjNum);
+ virtual SdrObject* ReplaceObject(SdrObject* pNewObj, sal_uLong nObjNum);
virtual void SetLinkData(const String& rLinkName, const String& rLinkData);
@@ -233,8 +233,8 @@ public:
void SetPageKind(PageKind ePgType) { mePageKind = ePgType; }
PageKind GetPageKind() const { return mePageKind; }
- void SetSelected(BOOL bSel) { mbSelected = bSel; }
- BOOL IsSelected() const { return mbSelected; }
+ void SetSelected(sal_Bool bSel) { mbSelected = bSel; }
+ sal_Bool IsSelected() const { return mbSelected; }
void SetFadeEffect(::com::sun::star::presentation::FadeEffect eNewEffect);
::com::sun::star::presentation::FadeEffect GetFadeEffect() const;
@@ -242,17 +242,17 @@ public:
void SetPresChange(PresChange eChange) { mePresChange = eChange; }
PresChange GetPresChange() const { return mePresChange; }
- void SetTime(UINT32 nNewTime) { mnTime = nNewTime; }
- UINT32 GetTime() const { return mnTime; }
+ void SetTime(sal_uInt32 nNewTime) { mnTime = nNewTime; }
+ sal_uInt32 GetTime() const { return mnTime; }
- void SetSound(BOOL bNewSoundOn) { mbSoundOn = bNewSoundOn; }
- BOOL IsSoundOn() const { return mbSoundOn; }
+ void SetSound(sal_Bool bNewSoundOn) { mbSoundOn = bNewSoundOn; }
+ sal_Bool IsSoundOn() const { return mbSoundOn; }
- void SetExcluded(BOOL bNewExcluded) { mbExcluded = bNewExcluded; }
- BOOL IsExcluded() const { return mbExcluded; }
+ void SetExcluded(sal_Bool bNewExcluded) { mbExcluded = bNewExcluded; }
+ sal_Bool IsExcluded() const { return mbExcluded; }
- void SetScaleObjects(BOOL bScale) { mbScaleObjects = bScale; }
- BOOL IsScaleObjects() const { return mbScaleObjects; }
+ void SetScaleObjects(sal_Bool bScale) { mbScaleObjects = bScale; }
+ sal_Bool IsScaleObjects() const { return mbScaleObjects; }
void SetSoundFile(const String& rStr) { maSoundFile = rStr; }
String GetSoundFile() const { return maSoundFile; }
@@ -295,24 +295,24 @@ public:
void DisconnectLink();
void ScaleObjects(const Size& rNewPageSize, const Rectangle& rNewBorderRect,
- BOOL bScaleAllObj);
+ sal_Bool bScaleAllObj);
const String& GetName() const;
String GetRealName() const { return FmFormPage::GetName(); };
void SetPresentationLayout(const String& rLayoutName,
- BOOL bReplaceStyleSheets = TRUE,
- BOOL bSetMasterPage = TRUE,
- BOOL bReverseOrder = FALSE);
+ sal_Bool bReplaceStyleSheets = sal_True,
+ sal_Bool bSetMasterPage = sal_True,
+ sal_Bool bReverseOrder = sal_False);
void EndListenOutlineText();
- void SetBackgroundFullSize( BOOL bIn );
- BOOL IsBackgroundFullSize() const { return mbBackgroundFullSize; }
+ void SetBackgroundFullSize( sal_Bool bIn );
+ sal_Bool IsBackgroundFullSize() const { return mbBackgroundFullSize; }
rtl_TextEncoding GetCharSet() { return(meCharSet); }
- void SetPaperBin(USHORT nBin) { mnPaperBin = nBin; }
- USHORT GetPaperBin() const { return mnPaperBin; }
+ void SetPaperBin(sal_uInt16 nBin) { mnPaperBin = nBin; }
+ sal_uInt16 GetPaperBin() const { return mnPaperBin; }
virtual void SetOrientation(Orientation eOrient);
virtual Orientation GetOrientation() const;